# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/mail/email_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/mail/email_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/mail/email_type.proto\x12\x0b\x65olymp.mail*b\n\tEmailType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x01\x12\x0e\n\nNEWSLETTER\x10\x02\x12\x0b\n\x07UPDATES\x10\x03\x12\x0e\n\nCOMMERCIAL\x10\x04\x12\t\n\x05OTHER\x10\x05\x42+Z)github.com/eolymp/go-sdk/eolymp/mail;mailb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mail.email_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/mail;mail'
  _globals['_EMAILTYPE']._serialized_start=45
  _globals['_EMAILTYPE']._serialized_end=143
# @@protoc_insertion_point(module_scope)
